@@ -264,7 +264,8 @@ class AutoPlot():
             save(fig)
     
     
-    def _plot_multibot_backtest(self, multibot_backtest_results, NAV, cpl_dict):
+    def _plot_multibot_backtest(self, multibot_backtest_results, NAV, cpl_dict,
+                                margin_available):
         ''' 
         Creates multi-bot backtest figure. 
         
@@ -454,11 +455,41 @@ class AutoPlot():
                 }
         cplfig.xaxis.bounds   = (0, self.data.index[-1])
         
+        # --------------------- Margin Available --------------------------- #
+        marfig = figure(plot_width = self.ohlc_width,
+                        plot_height = self.top_fig_height,
+                        title = None,
+                        active_drag = 'pan',
+                        active_scroll = 'wheel_zoom',
+                        x_range = navfig.x_range)
+        
+        # Add glyphs
+        marfig.line(self.data.index, 
+                    margin_available, 
+                    line_color = 'black',
+                    legend_label = 'Margin Available')
+        
+        marfig.xaxis.major_label_overrides = {
+                    i: date.strftime('%b %d') for i, date in enumerate(pd.to_datetime(self.data["date"]))
+                }
+        marfig.xaxis.bounds = (0, self.data.index[-1])
+        marfig.sizing_mode = 'stretch_width'
+        marfig.legend.location = 'top_left'
+        marfig.legend.border_line_width   = 1
+        marfig.legend.border_line_color   = '#333333'
+        marfig.legend.padding             = 5
+        marfig.legend.spacing             = 0
+        marfig.legend.margin              = 0
+        marfig.legend.label_text_font_size = '8pt'
+        marfig.add_tools(linked_crosshair)
+        
+        
         # -------------------- Construct final figure ---------------------- #     
         final_fig = layout([  
                                    [navfig],
                             [winrate, pie, plbars],
-                                   [cplfig]
+                                   [cplfig],
+                                   [marfig]
                         ])
         final_fig.sizing_mode = 'scale_width'
         show(final_fig)
@@ -485,7 +516,8 @@ class AutoPlot():
                      'over'        : 'over',
                      'below'       : 'below',
                      'Grid'        : 'over',
-                     'Pivot'       : 'over'}
+                     'Pivot'       : 'over',
+                     'HalfTrend'   : 'over'}
         
         # Plot indicators
         indis_over              = 0
@@ -502,7 +534,10 @@ class AutoPlot():
                     if indi_type == 'Supertrend':
                         self._plot_supertrend(indicators[indicator]['data'], 
                                               linked_fig)
-                        
+                        indis_over     += 1 # Count as 2 indicators
+                    elif indi_type == 'HalfTrend':
+                        self._plot_halftrend(indicators[indicator]['data'], 
+                                             linked_fig)
                         indis_over     += 1 # Count as 2 indicators
                     elif indi_type == 'Swings':
                         self._plot_swings(indicators[indicator]['data'], 
@@ -694,6 +729,39 @@ class AutoPlot():
                     fill_color = 'red',
                     legend_label = 'Down trend support')
     
+    def _plot_halftrend(self, htdf, linked_fig):
+        ''' Plots halftrend indicator. '''
+        # reset index 
+        htdf['date'] = htdf.index 
+        htdf = htdf.reset_index(drop = True)
+        long_arrows = htdf[htdf.buy != 0]
+        short_arrows = htdf[htdf.sell != 0]
+        
+        # Add glyphs
+        linked_fig.scatter(htdf.index,
+                           htdf['atrLow'],
+                           size = 3,
+                           fill_color = 'blue',
+                           legend_label = 'ATR Support')
+        linked_fig.scatter(htdf.index,
+                           htdf['atrHigh'],
+                           size = 3,
+                           fill_color = 'red',
+                           legend_label = 'ATR Resistance')
+        linked_fig.line(htdf.index,
+                           htdf['atrLow'],
+                           line_color = 'blue')
+        linked_fig.line(htdf.index,
+                           htdf['atrHigh'],
+                           line_color = 'red')
+        
+        # Add buy and sell entry signals
+        self._plot_trade(long_arrows.index, long_arrows.atrLow, 
+                         'triangle', 'green', 'Buy Signals', linked_fig, 10)
+        self._plot_trade(short_arrows.index, short_arrows.atrHigh, 
+                         'inverted_triangle', 'red', 'Sell Signals', 
+                         linked_fig, 10)
+    
     def _plot_grid(self, grid_levels, linked_fig, linewidth=0.5):
         for price in grid_levels:
             hline = Span(location=price, 
